'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var useScript = _interopDefault(require('react-script-hook'));

const generateScriptSrc = ({
  siteKey,
  lang
}) => {
  let baseSrc = `https://www.google.com/recaptcha/api.js?render=${siteKey}`;

  if (lang) {
    baseSrc = `${baseSrc}&hl=${lang}`;
  }

  return baseSrc;
};

const useRecaptcha = ({
  siteKey,
  lang
}) => {
  const [status, setStatus] = react.useState({
    loading: true,
    ready: false,
    error: null
  });

  const handleLoadScript = () => {
    window.grecaptcha.ready(() => {
      setStatus({
        loading: false,
        ready: true,
        error: null
      });
    });
  };

  const handleErrorScript = () => {
    setStatus({
      loading: false,
      ready: false,
      error: new Error('An error occurred while loading Recaptcha')
    });
  };

  const getRecaptchaToken = action => new Promise((resolve, reject) => {
    if (!status.ready) {
      reject(Error('Recaptcha script not yet loaded'));
    }

    window.grecaptcha.execute(siteKey, {
      action
    }).then(resolve, error => {
      if (!error) {
        reject(Error('Error while receiving token'));
      }

      reject(error);
    });
  });

  useScript({
    src: generateScriptSrc({
      siteKey,
      lang
    }),
    onload: handleLoadScript,
    onerror: handleErrorScript
  });
  return {
    status,
    getRecaptchaToken
  };
};

exports.default = useRecaptcha;
